@@ -51,8 +51,11 @@ def format_sql(sql, params):
 
     if isinstance(params, dict):
         conv = _FormatConverter(params)
-        sql = sql % conv
-        params = conv.params
+        if params:
+            sql = sql % conv
+            params = conv.params
+        else:
+            params = ()
 
     for param in params or ():
         if param is None:
@@ -94,7 +97,6 @@ def install_sql_hook():
             #   'default') ?
             data.update({
                 'message': real_sql,
-                'duration': duration,
                 'category': 'query',
             })
         breadcrumbs.record(processor=processor)
